@@ -14,8 +14,7 @@ for ($angle=0; $angle < 360; $angle+=30)
   my ($label);
 
   print "angle $angle\n";
-  $label=Image::Magick->new(size=>"600x600",pointsize=>24,font=>$font,
-    fill=>'black');
+  $label=Image::Magick->new(size=>"600x600",pointsize=>24,font=>$font);
   $label->Read("xc:white");
   $label->Draw(primitive=>'line',points=>"300,100 300,500",stroke=>'#600');
   $label->Draw(primitive=>'line',points=>"100,300 500,300",stroke=>'#600');
@@ -23,24 +22,19 @@ for ($angle=0; $angle < 360; $angle+=30)
     stroke=>'#600');
   $label->Annotate(text=>"North West",gravity=>"NorthWest",x=>$x,y=>$y,
     rotate=>$angle);
-  $label->Annotate(text=>"North",gravity=>"North",x=>$x,y=>$y,
-    rotate=>$angle);
+  $label->Annotate(text=>"North",gravity=>"North",y=>$y,rotate=>$angle);
   $label->Annotate(text=>"North East",gravity=>"NorthEast",x=>$x,y=>$y,
     rotate=>$angle);
-  $label->Annotate(text=>"West",gravity=>"West",x=>$x,y=>$y,
-    rotate=>$angle);
-  $label->Annotate(text=>"Center",gravity=>"Center",x=>$x,y=>$y,
-    rotate=>$angle);
-  $label->Annotate(text=>"East",gravity=>"East",x=>$x,y=>$y,
-    rotate=>$angle);
+  $label->Annotate(text=>"West",gravity=>"West",x=>$x,rotate=>$angle);
+  $label->Annotate(text=>"Center",gravity=>"Center",rotate=>$angle);
+  $label->Annotate(text=>"East",gravity=>"East",x=>$x,rotate=>$angle);
   $label->Annotate(text=>"South West",gravity=>"SouthWest",x=>$x,y=>$y,
     rotate=>$angle);
-  $label->Annotate(text=>"South",gravity=>"South",x=>$x,y=>$y,
-    rotate=>$angle);
+  $label->Annotate(text=>"South",gravity=>"South",y=>$y,rotate=>$angle);
   $label->Annotate(text=>"South East",gravity=>"SouthEast",x=>$x,y=>$y,
     rotate=>$angle);
   push(@$image,$label);
 }
 $image->Set(delay=>20);
-$image->Write(filename=>"annotate.miff",compress=>'RunlengthEncoded');
+$image->Write("annotate.miff");
 $image->Animate();
